@@ -1,8 +1,7 @@
 /* dictfmt.c -- 
  * Created: Sun Jul 20 20:17:11 1997 by faith@acm.org
- * Revised: Sat Sep 27 23:47:04 2003 by faith@acm.org
  * Copyright 1997, 1998, 2003 Rickard E. Faith (faith@acm.org)
- * Copyright 2002-2007 Aleksey Cheusov (vle@gmx.net)
+ * Copyright 2002-2008 Aleksey Cheusov (vle@gmx.net)
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -144,12 +143,6 @@ static void init (const char *fn)
    alphabet_pool = str_pool_create ();
 }
 
-static int print_alphabet (const void *symbol, void *arg)
-{
-   printf ("%s: %s\n", (char *) arg, (const char *) symbol);
-   return 0;
-}
-
 static void destroy (void)
 {
    str_pool_destroy (alphabet_pool);
@@ -247,7 +240,6 @@ static void fmt_string( const char *s )
 #if 0
    char *t;
 #endif
-   size_t  len;
 
    if (!str)
       return;
@@ -452,7 +444,6 @@ static void write_hw_to_index (
    int start, int end)
 {
    int len = 0;
-   char *trimmed_new_word = NULL;
    char *new_word = NULL;
 
    if (!word)
@@ -909,25 +900,41 @@ static void fmt_headword_for_url (void)
    ignore_hw_url = 1;
 }
 
+static int qsort_compare_strings (const void *a, const void *b)
+{
+   return strcmp (*(const char **)a, *(const char **)b);
+}
+
 static void fmt_headword_for_alphabet (void)
 {
    const char *key;
-   size_t len;
    size_t sum_size = 0;
    str_Position pos;
    char *alphabet;
+   int alphabet_size = 0;
+   const char **keys = NULL;
+   int i;
 
    fmt_newheadword("00-database-alphabet");
 
    STR_ITERATE (alphabet_pool, pos, key){
       sum_size += strlen (key);
+      ++alphabet_size;
    }
 
+   keys = xmalloc (alphabet_size * sizeof (keys [0]));
+
+   i = 0;
+   STR_ITERATE (alphabet_pool, pos, key){
+      keys [i++] = key;
+   }
+
+   qsort (keys, alphabet_size, sizeof (keys [0]), qsort_compare_strings);
+
    alphabet = xmalloc (sum_size + 1);
    alphabet [0] = 0;
-
-   STR_ITERATE (alphabet_pool, pos, key){
-      strcat (alphabet, key);
+   for (i=0; i < alphabet_size; ++i){
+      strcat (alphabet, keys [i]);
    }
 
    fmt_string (alphabet);
@@ -1033,7 +1040,6 @@ static void fmt_headword_for_casesensitive (void)
 static void fmt_headword_for_dictfmt_ver (void)
 {
    char ver [200];
-   char *p;
    snprintf (ver, sizeof (ver),
 	     "00-database-dictfmt-%s", DICT_VERSION);
 
@@ -1481,8 +1487,6 @@ int main( int argc, char **argv )
 	    const char *size     = NULL;
 	    const char *data     = NULL;
 
-	    size_t len = strlen (buffer);
-
 	    int i_offset = 0;
 	    int i_size   = 0;
 
@@ -1513,7 +1517,7 @@ int main( int argc, char **argv )
 	    }
 
 	    if (indexonly_base64){
-	       i_size = (int) b64_decode (offset);
+	       i_size = (int) b64_decode (size);
 	    }else{
 	       i_size = xatoi (size);
 	    }
